"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EncodedTSCFileSystemProvider = void 0;
const vscode = require("vscode");
const fs = require("fs");
class EncodedTSCFileSystemProvider {
    constructor() {
        this.onDidChangeFile = new vscode.EventEmitter().event;
    }
    watch(uri, options) {
        return new vscode.Disposable(() => { });
    }
    stat(uri) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const stat = yield fs.promises.stat(uri.fsPath);
                const type = stat.isSymbolicLink()
                    ? vscode.FileType.SymbolicLink
                    : stat.isDirectory()
                        ? vscode.FileType.Directory
                        : stat.isFile()
                            ? vscode.FileType.File
                            : vscode.FileType.Unknown;
                return {
                    type,
                    size: stat.size,
                    ctime: stat.ctimeMs,
                    mtime: stat.mtimeMs,
                };
            }
            catch (e) {
                throw vscode.FileSystemError.FileNotFound(uri);
            }
        });
    }
    readDirectory(uri) {
        return [];
    }
    createDirectory(uri) { }
    readFile(uri) {
        return __awaiter(this, void 0, void 0, function* () {
            const buf = yield fs.promises.readFile(uri.fsPath);
            const half = (buf.length / 2) | 0;
            const key = buf[half] === 0 ? 0xf9 : -buf[half] & 0xff;
            for (let i = 0; i < buf.length; i++) {
                if (i === half) {
                    continue;
                }
                buf[i] = (buf[i] + key) & 0xff;
            }
            console.log('Loaded encoded TSC', uri.fsPath, 'with key:', key);
            return buf;
        });
    }
    writeFile(uri, buf, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const half = (buf.length / 2) | 0;
            const key = buf[half] === 0 ? 0xf9 : -buf[half] & 0xff;
            for (let i = 0; i < buf.length; i++) {
                if (i === half) {
                    continue;
                }
                buf[i] = (buf[i] - key) & 0xff;
            }
            fs.writeFileSync(uri.fsPath, buf);
            console.log('Saved encoded TSC', uri.fsPath, 'with key:', key);
        });
    }
    delete(uri, options) { }
    rename(oldUri, newUri, options) { }
}
exports.EncodedTSCFileSystemProvider = EncodedTSCFileSystemProvider;
//# sourceMappingURL=EncodedTSCFileSystemProvider.js.map