"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const crypto = require("crypto");
const fs = require("fs");
const download_1 = require("./download");
const openpgp = require("openpgp");
const publicKey_1 = require("./publicKey");
const calculateFileChecksum = (filepath) => {
    return new Promise((resolve, reject) => {
        const hash = crypto.createHash('sha256');
        fs.createReadStream(filepath)
            .on('error', reject)
            .on('data', data => hash.update(data))
            .on('end', () => resolve(hash.digest('hex')));
    });
};
const downloadReleaseChecksum = (release) => __awaiter(void 0, void 0, void 0, function* () {
    const checksum = yield download_1.download(release.checksumsUrl);
    const signature = yield download_1.downloadBuffer(release.checksumsSignatureUrl);
    const verifiedMessage = yield openpgp.verify({
        message: openpgp.message.fromText(checksum),
        publicKeys: (yield openpgp.key.readArmored(publicKey_1.default)).keys,
        signature: yield openpgp.signature.read(signature)
    });
    const { valid } = verifiedMessage.signatures[0];
    if (!valid) {
        throw new Error('Failed to verify checksum signature.');
    }
    const target = checksum.split('\n').find(r => r.includes(release.name));
    if (!target) {
        throw new Error(`No checksum found for ${release.name}.`);
    }
    return target.split(/\s/g)[0];
});
const verifyIntegity = (release, filepath) => __awaiter(void 0, void 0, void 0, function* () {
    const binaryChecksum = yield calculateFileChecksum(filepath);
    const actualChecksum = yield downloadReleaseChecksum(release);
    if (binaryChecksum !== actualChecksum) {
        throw new Error(`Checksum verification failed for ${release.name}: calculated "${binaryChecksum}" doesn't match actual "${actualChecksum}".`);
    }
});
exports.default = verifyIntegity;
//# sourceMappingURL=integrity.js.map